==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/DataSourceSpecialRowDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridSummaryResultDescriptionMetadata } from "./DataGridSummaryResultDescriptionMetadata";
import { DataSourceSpecialRowDescription } from "./DataSourceSpecialRowDescription";
/**
 * @hidden
 */
export let DataSourceSpecialRowDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataSourceSpecialRowDescriptionMetadata extends Base {
        static b(a) {
            if (DataSourceSpecialRowDescriptionMetadata.a == null) {
                DataSourceSpecialRowDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataSourceSpecialRowDescriptionMetadata.c(DataSourceSpecialRowDescriptionMetadata.a);
            }
            if (a.j(DataSourceSpecialRowDescriptionMetadata.a)) {
                return;
            }
            a.y(DataSourceSpecialRowDescriptionMetadata.a);
            DataGridSummaryResultDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("RowType", "ExportedType:string:DataSourceRowType");
            a.item("RowType@names", "Normal;SectionHeader;SectionFooter;ShiftedRow;SummaryRowRoot;SummaryRowSection;Custom");
            a.item("TargetRow", "Unknown");
            a.item("Level", "Number:int");
            a.item("SummaryResults", "Array:DataGridSummaryResultDescription:ISummaryResult");
        }
        static d(a) {
            DataSourceSpecialRowDescriptionMetadata.b(a);
            a.aa("DataSourceSpecialRow", () => new DataSourceSpecialRowDescription());
            a.z("DataSourceSpecialRow", DataSourceSpecialRowDescriptionMetadata.a);
        }
    }
    DataSourceSpecialRowDescriptionMetadata.$t = /*@__PURE__*/ markType(DataSourceSpecialRowDescriptionMetadata, 'DataSourceSpecialRowDescriptionMetadata');
    DataSourceSpecialRowDescriptionMetadata.a = null;
    return DataSourceSpecialRowDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/DataSourceSpecialRowDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridSummaryResultDescriptionMetadata } from "./DataGridSummaryResultDescriptionMetadata";
import { DataSourceSpecialRowDescription } from "./DataSourceSpecialRowDescription";
/**
 * @hidden
 */
export let DataSourceSpecialRowDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataSourceSpecialRowDescriptionMetadata extends Base {
        static b(a) {
            if (DataSourceSpecialRowDescriptionMetadata.a == null) {
                DataSourceSpecialRowDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataSourceSpecialRowDescriptionMetadata.c(DataSourceSpecialRowDescriptionMetadata.a);
            }
            if (a.k(DataSourceSpecialRowDescriptionMetadata.a)) {
                return;
            }
            a.aa(DataSourceSpecialRowDescriptionMetadata.a);
            DataGridSummaryResultDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("RowType", "ExportedType:string:DataSourceRowType");
            a.item("RowType@names", "Normal;SectionHeader;SectionFooter;ShiftedRow;SummaryRowRoot;SummaryRowSection;Custom");
            a.item("TargetRow", "Unknown");
            a.item("Level", "Number:int");
            a.item("SummaryResults", "Array:DataGridSummaryResultDescription:ISummaryResult");
        }
        static d(a) {
            DataSourceSpecialRowDescriptionMetadata.b(a);
            a.ac("DataSourceSpecialRow", () => new DataSourceSpecialRowDescription());
            a.ab("DataSourceSpecialRow", DataSourceSpecialRowDescriptionMetadata.a);
        }
    }
    DataSourceSpecialRowDescriptionMetadata.$t = /*@__PURE__*/ markType(DataSourceSpecialRowDescriptionMetadata, 'DataSourceSpecialRowDescriptionMetadata');
    DataSourceSpecialRowDescriptionMetadata.a = null;
    return DataSourceSpecialRowDescriptionMetadata;
})();
